@@ -192,7 +192,7 @@ class DBoperator(object):
         """
         url = self.url
         conn = psycopg2.connect(url)
-        sql = "select id from graph_calculation where graph_name=\'" + graph_name + "\' "
+        sql = "select id from graph_calculation where subgraph_id=\'" + graph_name + "\' "
         ids = []
         with conn.cursor() as cur:
             cur.execute(sql)
@@ -203,15 +203,16 @@ class DBoperator(object):
                 return None
             self.graph_name = graph_name
             logger.info("get_id [" + graph_name + "] done")
-            ids = rows[0]
+            for i in range(len(rows)):
+                ids.append(rows[i][0])
             conn.close()
         task_ids = []
         for id in ids:
             task_id = self.get_one_task(id)
             if task_id:
-                task_ids.append(task_id)
+                task_ids.append("\'"+str(task_id)+"\'")
 
-        return rows
+        return task_ids
     def get_one_task(self, id):
         """
         获取计算任务id
@@ -219,7 +220,7 @@ class DBoperator(object):
         url = self.url
         conn = psycopg2.connect(url)
         sql = "select id,operation_state from calculation_state where" \
-              " graph_calculation_id=\'" + id + "\' order by update_time limit 1"
+              " graph_calculation_id=\'" + str(id) + "\' order by update_time desc limit 1"
         task_id = None
         with conn.cursor() as cur:
             cur.execute(sql)
@@ -229,7 +230,7 @@ class DBoperator(object):
                 logger.warning("get_one_task does not exist")
                 return None
             logger.info("get_one_task done")
-            if rows[1][0] == 1:
+            if rows[0][1] == 1:
                 task_id = rows[0][0]
             conn.close()
         return task_id
