@@ -149,7 +149,7 @@ class CHGraph(object):
         if target_field_list is None:
             target_field_list_con += "," + ",".join(edge_info["fields"])
         elif type(target_field_list) == list and len(target_field_list) > 0:
-            target_field_list_con += "," + ",".join(target_field_list)
+            target_field_list_con += "," + ",".join(edge_info["fields"]) + "," + ",".join(target_field_list)
         elif type(target_field_list) == str and target_field_list == "src":
             target_field_list_con = "DISTINCT " + edge_info["src"]
         elif type(target_field_list) == str and target_field_list == "dst":
@@ -785,7 +785,10 @@ class CHGraph(object):
                     src_info = self.graph_cfg["vertexes"][edge_info["src_type"]]
                     src_db_table_new = subgraph_name + "." + src_info["table"]
                     src_db_table_old = main_db + "." + src_info["table"]
+
                     src_target_field_list_con = src_info["id"] + "," + ",".join(src_info["fields"])
+                    if "_time" not in src_info["fields"]:
+                        src_target_field_list_con = src_target_field_list_con + ",_time"
                     self.client.execute(
                         "insert into " + src_db_table_new + " (" + src_target_field_list_con + ") select distinct " + src_target_field_list_con + " from " + src_db_table_old + " where " +
                         src_info["id"] + " in " + tostr(col_list[0]))
@@ -793,6 +796,9 @@ class CHGraph(object):
                     dst_db_table_new = subgraph_name + "." + dst_info["table"]
                     dst_db_table_old = main_db + "." + dst_info["table"]
                     dst_target_field_list_con = dst_info["id"] + "," + ",".join(dst_info["fields"])
+                    if "_time" not in dst_info["fields"]:
+                        dst_target_field_list_con = dst_target_field_list_con + ",_time"
+
                     self.client.execute(
                         "insert into " + dst_db_table_new + " (" + dst_target_field_list_con + ") select distinct " + dst_target_field_list_con + " from " + dst_db_table_old + " where " +
                         dst_info["id"] + " in " + tostr(col_list[1]))
