@@ -67,7 +67,7 @@ from controllers.graph import GetInfoData,\
     MetricOutdegreeHandler, VertexQueryHandler, VertexMatchPropertyHandler,\
     EdgeQueryHandler, EdgeMatchPropertyHandler, TimeStaticSubgraphHandler,\
     GainSubgraph, GainSubgraphQuery, GainTimeLineCount, GainCountEdges,\
-    GainGraphTypeSet, GainGraphTypeFunction, GainGraphTypeCount
+    GainGraphTypeSet, GainGraphTypeFunction, GainGraphTypeCount, GainGraphTaskSelect, GainGraphTaskSubmit
 
 
 logger = get_logger()
@@ -552,6 +552,10 @@ class Application(tornado.web.Application):
                         {"config_params": config_params}),
         tornado.web.url(r"/graph-db/api/v1/subgraph-type-statistics-function", GainGraphTypeFunction,
                         {"config_params": config_params}),
+        tornado.web.url(r"/graph-db/api/v1/subgraph-calculation-select", GainGraphTaskSelect,
+                        {"config_params": config_params}),
+        tornado.web.url(r"/graph-db/api/v1/subgraph-calculation-submit", GainGraphTaskSubmit,
+                        {"config_params": config_params}),
     ]
 
     def get_routes(self):
