@@ -1498,42 +1498,23 @@ def model_service_metric_pagerank(data, config_params):
 
 
 def model_service_vertex_match_property(data, config_params):
-    if "graph_name" in data.keys():
-        graph_name = data["graph_name"]
-    else:
+    graph_name = data.get("graph_name")
+    if not graph_name:
         return "graph_name shouldn't be null"
 
-    if "vertex_id_list" in data.keys():
-        vertex_id_list = data["vertex_id_list"]
-    else:
+    vertex_id_list = data.get("vertex_id_list")
+    if not vertex_id_list:
         return "vertex_id_list shouldn't be null"
 
-    if "vertex_name" in data.keys():
-        vertex_name = data["vertex_name"]
-    else:
+    vertex_name = data.get("vertex_name")
+    if not vertex_name:
         return "vertex_name shouldn't be null"
 
-    if "vertex_con_list" in data.keys():
-        vertex_con_list = data["vertex_con_list"]
-    else:
-        vertex_con_list = None
+    vertex_con_list = data.get("vertex_con_list")
+    target_field_list = data.get("target_field_list")
+    page = data.get("page")
+    page_size = data.get("page_size")
 
-    if "target_field_list" in data.keys():
-        target_field_list = data["target_field_list"]
-    else:
-        target_field_list = None
-    if "page" in data.keys():
-        page = data["page"]
-    else:
-        page = None
-    if "page_size" in data.keys():
-        page_size = data["page_size"]
-    else:
-        page_size = None
-
-    # client = Client('10.217.62.41')
-    #
-    # graph = CHGraph(client)
     graph = config_params["graph"]
     db = config_params["db"]
     graph.use_graph(graph_name, db)
@@ -1548,7 +1529,7 @@ def model_service_vertex_match_property(data, config_params):
                                                       )
         return vertex_property
     except Exception as e:
-        print(e)
+        logger.error("model_service_vertex_match_property error: {}".format(str(e)))
         return "vertex match property failed"
 
 
